
;*********************************************************************************************************************
;                                                                                                                    *
;     Funktion zum Erstellen dynamischer Dialogboxen whrend der Laufzeit eines Lisp-Programmes                      *
;                                                                                                                    *
;*********************************************************************************************************************
; Der Befehl vox-build-dynamic-dcl-data erstellt eine temporre Dialogboxdatei, die die in der bergabeliste         *
; definierten DCL-Elemente enthlt. Zurckgegeben wird der Name der temporren Datei. Es sollte darauf geachtet      *
; werden, die temporre DCL-Datei zu lschen, wenn sie nicht mehr verwendet wird. Alle bergebenen Werte sind        *
; Strings.                                                                                                           *
;                                                                                                                    *
; Aufbau der bergabe-Liste fr die dynamic-dialog-box:                                                              *
; (Dialogname (daten) ((feld) (feld) (feld) (feld))) oder (Dialogname (daten) (feld) (feld) (feld) (feld))           *
;                                                                                                                    *
; Felder (feld) bei Layouttypen (column, row etc):                                                                   *
; (typ (daten) ((feld) (feld) (feld))) oder (typ (daten) (feld) (feld) (feld))                                       *
;                                                                                                                    *
; Felder (feld) bei Objekttypen (text, list, button etc):                                                            *
; (typ (daten))                                                                                                      *
;                                                                                                                    *
; Felder (feld) bei vordefinierten Objekten ("spacer" "spacer_0" "spacer_1" "ok_only" "ok_cancel" "ok_cancel_help" ..*
; (typ)                                                                                                              *
;                                                                                                                    *
; Daten (daten):                                                                                                     *
; ((attribut wert) (attribut wert) (attribut wert))                                                                  *
;                                                                                                                    *
;*********************************************************************************************************************


(defun vox-build-dynamic-dcl-data (liste / my_dcl file_id n)
  (setq my_dcl (vl-filename-mktemp "tmp.dcl")); temporren dcl-Namen erzeugen
  (setq file_id (open my_dcl "w")) ; und zum Schreiben ffnen
  (write-line (strcat (car liste) " : dialog {") file_id); Dialogname und beginn erzeugen
  (foreach n (cadr liste); Felddaten verarbeiten
    (if (member (car n) '("initial_focus" "key" "label" "list" "mnemonic" "password_char" "value" "tabs" "action"))
      (write-line (strcat (car n) " = " (vl-prin1-to-string (cadr n)) ";") file_id); als String in "" schreiben
      (write-line (strcat (car n) " = " (cadr n) ";") file_id); als normalen String schreiben
    )
  )
  (foreach n (cddr liste) (vox-write-dynamic-dcl-data n file_id)); restliche Liste abarbeiten
  (write-line "}" file_id); Dialog schliessen
  (close file_id); Datei schliessen
  (setq my_dcl my_dcl); Dateiname zurckgeben
)



(defun vox-write-dynamic-dcl-data (data file_id / n typ)
  (setq typ (car data)); Typ des ersten Eintrags der Daten ermitteln
  (if (= 'LIST (type typ)); wenn Liste, liegt "verschachtelte" Liste vor, also...
    (foreach n data (vox-write-dynamic-dcl-data n file_id)); ... fr jedes Schachtelelement rekursiven Aufruf durchfhren
    (if (member typ '("column" "boxed_column" "radio_column" "boxed_radio_column" "row" "boxed_row" "radio_row" "boxed_radio_row" "concatenation" "paragraph"))
      (progn; sonst, wenn erstes Element Layoutanweisungen enthlt
        (write-line (strcat ":" (car data) " {") file_id); Layoutdaten schreiben, und ...
        (foreach n (cadr data); ... Attribute verarbreiten
          (if (member (car n) '("initial_focus" "key" "label" "list" "mnemonic" "password_char" "value" "tabs" "action"))
            (write-line (strcat (car n) " = " (vl-prin1-to-string (cadr n)) ";") file_id)
            (write-line (strcat (car n) " = " (cadr n) ";") file_id)
          )
        )
        (foreach n (cddr data) (vox-write-dynamic-dcl-data n file_id)); dann restliche Felder wieder rekursiv untersuchen
        (write-line "}" file_id); Layoutelement schliessen
      ); Ende: Wenn Layoutelement
      (if (member typ '("spacer" "spacer_0" "spacer_1" "errtile" "ok_only" "ok_cancel" "ok_cancel_help" "ok_cancel_help_info" "ok_cancel_err" "ok_cancel_help_errtile"))
        (write-line (strcat typ ";") file_id); sonst, wenn es ein vordefiniertes Objekt ist, nur typ schreiben
        (progn; ansonsten ist es ein Objektfeld:
          (write-line (strcat ":" typ " {") file_id); Objektfeld: beginnen
          (foreach n (cadr data); Datenliste des Objektes verarbeiten
            ;stringtypen: initial_focus, key, label, list, mnemonic, password_char,value
            (if (member (car n) '("initial_focus" "key" "label" "list" "mnemonic" "password_char" "value" "tabs" "action"))
              (write-line (strcat (car n) " = " (vl-prin1-to-string (cadr n)) ";") file_id)
              (write-line (strcat (car n) " = " (cadr n) ";") file_id)
            )
          )
          (write-line "}" file_id); Objektfeld schliessen
        )
      )
    )
  )
)


(defun c:konvert-dcl2liste ( / lspdatei dcldatei dialogline line kommentar ak_dialog openstart closestart dlg_liste dlg_start dlg_end dlg_name my_dcl_list file_id
                            data_needed pre_m dlg_body att_list no_more_att att_name att_wert end_data id ak_data dcl_temp_file ergebniss split_list ak_dialog2)
  (setq dcldatei (getfiled "DCL-Datei whlen..." "" "dcl" 0))
  (setq lspdatei (getfiled "LSP-Datei angeben..." dcldatei "lsp" 33))
  (setq dialogline "")
  (if dcldatei
    (progn
      (setq dcldatei (open dcldatei "r"))
      (setq line (read-line dcldatei))
      (while line
        (if (setq kommentar (in-string line "//"))
          (setq line (substr line 1 (1- kommentar)))
        )
        (if (setq kommentar (in-string line "/*"))
          (setq line (substr line 1 (1- kommentar)))
        )
        (setq line (get-real-string line));fhrende + folgende Leerzeichen lschen
        (if line
          (setq dialogline (strcat dialogline line))
        )
        (setq line (read-line dcldatei))
      )
      (close dcldatei)
      ;OK, jetzt string verarbeiten...
      (setq ak_dialog "")
      (while (/= dialogline "")
        (setq openstart (in-string dialogline "{"));nchste offenklammer
        (setq closestart (in-string dialogline "}"));nchste schliessklammer
        (if openstart ;ist am Ende nil
          (if (> openstart closestart)
            (progn;nchste klammer ist schliessklammer
              (setq ak_dialog (strcat ak_dialog (substr dialogline 1 (1- closestart)) ":}:"))
              (setq dialogline (substr dialogline (1+ closestart)))
            )
            (progn;nchste klammer ist offenklammer
              (setq ak_dialog (strcat ak_dialog (substr dialogline 1 (1- openstart)) ":{:"))
              (setq dialogline (substr dialogline (1+ openstart)))
            )
          )
          (progn;Am Ende sind nur noch schliessklammer
            (setq ak_dialog (strcat ak_dialog (substr dialogline 1 (1- closestart)) ":}:"))
            (setq dialogline (substr dialogline (1+ closestart)))
          )
        )
      )
    )
  )
  (setq dlg_liste nil)
  (setq ak_dialog (string-split ak_dialog ":"))
  (foreach n ak_dialog (setq ak_dialog2 (cons (get-real-string n) ak_dialog2)))
  (setq ak_dialog (reverse ak_dialog2))
  (while (setq dlg_start (member "dialog" ak_dialog))
    (setq dlg_name (nth (1- (- (length ak_dialog) (length dlg_start))) ak_dialog))
    (setq ak_dialog (cdr dlg_start))
    (setq dlg_end (member "dialog" ak_dialog))
    (if dlg_end ;weitere Dialoge folgen
      (setq dlg_liste (cons (list dlg_name (get-sub-list ak_dialog 1 (- (length ak_dialog) (1+ (length dlg_end))))) dlg_liste))
      (setq dlg_liste (cons (list dlg_name ak_dialog) dlg_liste))
    )
  )
  (if lspdatei
    (setq my_dcl_list lspdatei)
    (setq my_dcl_list (vl-filename-mktemp "lst.tmp"))
  )
  (setq file_id (open my_dcl_list "w"))
  (setq data_needed nil)
  (if lspdatei
    (progn
      (princ ";\n" file_id)
      (princ ";diese Lispdatei wurde automatisch erzeugt durch das Programm konvert-dcl2liste.\n" file_id)
      (princ ";Sie enthlt die Variablendefinitionen fr den Aufruf der Funktion vox-build-dynamic-dcl-data.\n" file_id)
      (princ ";folgende Variablen werden definiert:\n" file_id)
      (foreach n dlg_liste (princ (strcat ";Dialogname: " (car n) " ------- Variablenname: Ersatz_Variable_" (car n) "\n") file_id))
      (princ ";\n" file_id)
      (princ ";\n" file_id)
      (princ "(setq Ersatz_Variable " file_id)
    )
  )
  (princ "(list " file_id)
  (foreach n dlg_liste
    (progn
      (setq pre_m (car n))
      (if lspdatei
        (princ (strcat "(setq Ersatz_Variable_" pre_m " ") file_id)
      )
      (setq dlg_body (cadr n))
      (foreach m dlg_body
        (progn
          (cond
            ((= m "{")
             (progn
               (if data_needed (princ nil file_id))
               (princ (strcat "(list" (vl-prin1-to-string pre_m)) file_id)
               (setq data_needed t)
               (setq pre_m nil)
             )
            )
            ((= m "}")
             (progn
               (if data_needed
                 (progn
                   (princ nil file_id)
                   (setq data_needed nil)
                 )
               )
               (princ ")" file_id)
             )
            )

            ((= (substr m (strlen m)) ";")
             (progn
               (if pre_m (setq m (strcat pre_m ":" m) pre_m nil));attribute wurden getrennt, da im Label ein ":" enthalten war...
               (setq split_list (string-split m ";"))
               (if (= (length (string-split (car split_list) "=")) 1);vordefiniert
                 (progn
                   (if data_needed
                     (progn
                       (princ nil file_id)
                       (setq data_needed nil)
                     )
                   )
                   (foreach o split_list;falls mehrere vordefinierte Felder aufeinander folgen
                     (princ (strcat "(list" (vl-prin1-to-string (get-real-string o)) ")") file_id)
                   )
                 )
                 (progn
                   (princ "(list" file_id)
                   (foreach o split_list
                     (progn
                       (setq att_list (string-split o "="))
                       (if (= (length att_list) 1);vordefiniert folgt direkt auf attribute!
                         (progn
                           (if (not no_more_att) (princ ")" file_id));attributliste schliessen
                           (setq no_more_att t)
                           (princ (strcat "(list" (vl-prin1-to-string (get-real-string (car att_list))) ")") file_id)
                         )
                         (if (not no_more_att)
                           (progn
                             (if (> (length att_list) 2);Gleichheitszeichen als Wert
                               (setq att_list (list (car att_list) "\"=\""))
                             )
                             (if (= (type (read (setq att_name (car att_list)))) 'STR) (setq att_name (read att_name)))
                             (if (= (type (read (setq att_wert (cadr att_list)))) 'STR) (setq att_wert (read att_wert)))
                             (setq att_name (get-real-string att_name) att_wert (get-real-string att_wert))
                             (if (not att_name) (setq att_name ""))
                             (if (not att_wert) (setq att_wert ""))
                             (princ (strcat "(list" (vl-prin1-to-string att_name) (vl-prin1-to-string att_wert) ")") file_id)
                           )
                         )
                       )
                     )
                   )
                   (if (not no_more_att) (princ ")" file_id));attributliste schliessen
                   (setq no_more_att nil)
                   (setq data_needed nil)
                 )
               )
             )
            )
            (t (setq pre_m m))
          )
        )
      )
      (if lspdatei
        (princ ")" file_id)
      )
    )
  )
  (princ ")" file_id)
  (if lspdatei
    (princ ")" file_id)
  )
  (close file_id)
  (setq file_id (open my_dcl_list "r"))
  (while (= (substr (setq end_data (read-line file_id)) 1 1) ";"))
  (close file_id)
  (if (not lspdatei)
    (vl-file-delete my_dcl_list)
  )
  (setq end_data (eval (read end_data)))
  (setq zaehler 1)
  (if (> (length end_data) 1)
    (progn
      (textscr)
      (prompt "\n")
      (foreach n end_data
        (progn
          (prompt (strcat (itoa zaehler) " - " (car n) "\n"))
          (setq zaehler (1+ zaehler))
        )
      )
      (setq zaehler (getint "Bitte Nummer eingeben: "))
      (setq ak_data (nth (1- zaehler) end_data))
    )
    (setq ak_data (car end_data))
  )
;  (prin1 ak_data)
;  (foreach n ak_data (progn (prin1 n) (prompt "\n")))
  (setq id (load_dialog (setq dcl_temp_file (vox-build-dynamic-dcl-data ak_data))));dcl-Datei mittels Definition in "buttons_dcl" erzeugen und laden
  (if (not (new_dialog (car ak_data) id)) (exit))
  (setq ergebnis (start_dialog))
  (unload_dialog id)
  (vl-file-delete dcl_temp_file); nicht vergessen, temporre dcl-DAtei wieder zu lschen!
  (if lspdatei
    (alert (strcat "Die Datei \n" lspdatei "\nenthlt nun die Listendefinitionen\nfr die Dialogboxen.\n"))
    (setq ak_data ak_data)
  )
)


;tauscht im String <string> den wert <alt> gegen <neu> aus
(defun string-subst-all (string alt neu / lg pos)
  (if (and (= (type string) 'STR) (= (type alt) 'STR) (= (type neu) 'STR))
    (if (> (strlen alt) 0)
      (progn
        (setq lg (strlen alt))
        (setq pos (in-string string alt))
        (while pos
            (setq string (strcat (substr string 1 (1- pos)) neu (substr string (+ pos lg))))
          (setq pos (in-string string alt))
        )
      )
    )
  )
  (setq string string)
)


;get-sub-liste gibt die Elemente <start> bis <ende> der Liste <liste> zurck
(defun get-sub-list (liste start ende / return)
  (setq start (1- start))
  (while (< start ende)
    (setq return (cons (nth start liste) return))
    (setq start (1+ start))
  )
  (setq return (reverse return))
)



;testtet, ob String <str> in String <test> enthalten ist und gibt die Position des 1. Vorkommens zurck

(defun in-string (str test / a b c d l)
  (if (and (= (type str) 'STR) (= (type test) 'STR))
    (progn
      (setq a (strlen str))
      (setq l (strlen test))
      (setq c (substr str 1 l))
      (setq b 1 d nil)
      (while (and (not d) (<= b a))
        (setq c (substr str b l))
        (if (= c test) (setq d b))
        (setq b (1+ b))
      )
      (setq d d)
    )
  )
)



;fhrende + folgende Leerzeichen und tabs lschen
(defun get-real-string (str / a b c d)
  (if (and (= (type str) 'STR) (/= str ""))
    (progn
      (setq a (strlen str));a ist Lnge von String
      (setq b 1 c (substr str 1 1));b ist untersuchungsposition, c ist String an position b
      (while (and (<= b a) (member c '(" " "\t")))
        (setq b (1+ b))
        (setq c (substr str b 1))
      );b ist start
      (if (> (strlen c) 0)
        (progn
          (setq e (strlen (substr str b)))
          (setq d 0 c (substr str a 1))
          (while (and (<= d e) (member c '(" " "\t")))
            (setq c (substr str (- a (setq d (1+ d))) 1))
          )
          (setq c (substr str b (1+ (- a b d))))
          (if (= c "") (setq c nil) (setq c c))
        )
      )
    )
  )
)



; trennt einen String in Unterstrings, die durch einen (oder eine Folge von) Trenner getrennt werden.   
; gibt Liste der Unterstrings zurck (oder nil, wenn nur Trenner vorhanden sind)                        
; z.B. (str_split "12.3 23 werwe 34.7" " ") ergibt ("12.3" "23" "werwe" "34.7")                         
;      (str_split "12....3" ".")               ergibt ("12" "3")                                        
;      (str_split "......." ".")            ergibt nil                                                  

(defun string-split (str trenner / str_lg trenn_lg 1_st_let str_list trenn_list zaehler split_list)
  (if str
    (progn
      (setq str_lg (strlen str))
      (if (= (type trenner) 'STR)
        (progn
          (setq trenn_lg (strlen trenner))
          (if (> trenn_lg 0)
            (progn
              (while (/= str "")
                (setq 1st_let (substr str 1 1)
                      str_list (cons 1st_let str_list)
                      trenn_list (cons (substr str 1 trenn_lg) trenn_list)
                      str (substr str 2)
                )
              )
              (setq str_list (reverse str_list)
                    trenn_list (reverse trenn_list)
               )
              (setq zaehler 0)
              (while (< zaehler str_lg)
              ;(foreach n str_list
                (if (= (nth zaehler trenn_list) trenner)
                  (if (/= str "")
                    (setq split_list (cons str split_list) str ""
                          zaehler (+ zaehler trenn_lg)
                    )
                    (setq str ""
                          zaehler (+ zaehler trenn_lg)
                    )
                  )
                  (setq str (strcat str (nth zaehler str_list))
                        zaehler (1+ zaehler)
                  )
                )
              )
              (if (/= str "")
                (setq split_list (cons str split_list) str "")
              )
              (setq split_list (reverse split_list))
            )
            (setq split_list (list str))
          )
        )
        (setq split_list (list str))
      )
    )
    (setq split_list nil)
  )
  (setq split_list split_list)
)


;wie string_split, erzeugt aber Leerstrings, bei einer Folge von Trennern 

(defun string-split1 (str trenner / str_lg trenn_lg 1_st_let str_list trenn_list zaehler split_list)
  (if str
    (progn
      (setq str_lg (strlen str))
      (if (= (type trenner) 'STR)
        (progn
          (setq trenn_lg (strlen trenner))
          (if (> trenn_lg 0)
            (progn
              (while (/= str "")
                (setq 1st_let (substr str 1 1)
                      str_list (cons 1st_let str_list)
                      trenn_list (cons (substr str 1 trenn_lg) trenn_list)
                      str (substr str 2)
                )
              )
              (setq str_list (reverse str_list)
                    trenn_list (reverse trenn_list)
               )
              (setq zaehler 0)
              (while (< zaehler str_lg)
              ;(foreach n str_list
                (if (= (nth zaehler trenn_list) trenner)
                    (setq split_list (cons str split_list) str ""
                          zaehler (+ zaehler trenn_lg)
                    )
                  (setq str (strcat str (nth zaehler str_list))
                        zaehler (1+ zaehler)
                  )
                )
              )
              (if (/= str "")
                (setq split_list (cons str split_list) str "")
              )
              (setq split_list (reverse split_list))
            )
            (setq split_list (list str))
          )
        )
        (setq split_list (list str))
      )
    )
    (setq split_list nil)
  )
  (setq split_list split_list)
)





  
;*********************************************************************************************************************
;                                                                                                                    *
; Beispiele:                                                                                                         *
;                                                                                                                    *
;*********************************************************************************************************************

;1. Vordefinieren von Texten
(setq vox_ok " O K "
      vox_cancel "OOPS"
      vox_help "H?"
      vox_buttons (list "button" (list "Optionen" "Texte" "Listen" "Popups"))
      vox_optionen (list "radio_button" (list "Option"))
      vox_texte (list "text" (list "Text"))
      vox_listen (list "list_box" (list "Liste"))
      vox_popups (list "popup_list" (list "PopUp"))
)

;2. Vordefinieren von Teilelementen
(setq vox_ok_cancel_help ;ok_cancel_help mit copyright und Logo
       (list
         (list "row"
               (list (list "alignment" "centered") (list "fixed_width" "true"))
               (list "button"
                     (list (list "label" vox_ok) (list "key" "accept") (list "is_default" "true"))
                     )
               (list "button"
                     (list (list "label" vox_cancel) (list "key" "cancel") (list "is_cancel" "true"))
                     )
               (list "button"
                     (list (list "label" vox_help) (list "key" "help") (list "is_help" "true"))
                     )
               )
         (list "spacer")
         (list "row"
               nil
               (list "image"
                     (list (list "key" "VOX_img") (list "alignment" "left"))
                     )
               (list "text"
                     (list (list "label" "(c) H. Jesse 2004") (list "alignment" "centered"))
                     )
               )
         )
      vox_add_del ;zeile mit + und - Knopf
       (list
         (list "row"
               (list (list "alignment" "centered"))
               (list "button"
                     (list (list "label" "+") (list "key" "add"))
                     )
               (list "button"
                     (list (list "label" "-") (list "key" "del"))
                     )
               )
      )
 )

;3. Beispielfunktionen zum Erstellen von Teilelementlisten (hier key=label).
;   Hier wird fr jeden Eintrag in einer Liste ein Objekt entsprechend dem bergebenen Typ erzeugt.
;   Z.B ...("button" '("Knopf1" "Knopf2" "Knopf3") (list (list "with" "30") (list "fixed_width" "true")))
;   erzeugt 3 Buttons mit Label+Key Knopf 1-3 und zustzlichem fixen Breitenattribut 30
(defun vox-build-dcl-part-data (typ liste data / dummy n)
  (foreach n (reverse liste)
    (if data
      (setq dummy (cons (list typ (append (list (list "label" n) (list "key" n)) data)) dummy))
      (setq dummy (cons (list typ (list (list "label" n) (list "key" n))) dummy))
    )
  )
  (setq dummy dummy)
)
  

;4. Vordefinieren von ganzen Dialogboxen:
(setq buttons_dcl
       (list
         "buttons"; name der Dialogbox
         (list (list "label" "Buttonstest"));attribute
         (list "spacer");in DCL vordefiniertes Feld
         (vox-build-dcl-part-data (car vox_buttons) (cadr vox_buttons) nil);dynamisch erzeugte Teildatenliste aus der Liste vox_buttons (s.o.)
         (list "spacer")
         vox_ok_cancel_help; oben vordefinierte Liste
         )
      )


;Beispiel des Aufrufs und Verarbeitung der dynamischen Dialogboxen
(defun c:dcltest ( / dcl_buttons dcl_temp_file n ergebnis)
  (setq dcl_buttons (load_dialog (setq dcl_temp_file (vox-build-dynamic-dcl-data buttons_dcl))));dcl-Datei mittels Definition in "buttons_dcl" erzeugen und laden
  (if (not (new_dialog (car buttons_dcl) dcl_buttons)) (exit))
  (foreach n (cadr vox_buttons)
    (action_tile n (strcat "(setq "  (strcat "vox_" n ) "(vox-new-dlg \"" n "\" " (strcat "vox_" n "))")))
  )
  (vox-zeig-logo)
  (setq ergebnis (start_dialog))
  (unload_dialog dcl_buttons)
  (vl-file-delete dcl_temp_file); nicht vergessen, temporre dcl-Datei wieder zu lschen!
  (alert "Cool, was?\n")
  (setq ergebnis ergebnis);
)


;Beispiel zum dynamischen Erstellen von Dialogboxen
(defun vox-new-dlg (name data / typ name_dcl dcl_name dcl_temp_file temp_data weiter)
  (setq typ (car data) temp_data (cadr data))
  (setq weiter 2)
  (while (> weiter 1)
    (progn
      (setq name_dcl; Liste zur Erzeugung der DCL-DAtei erstellen
             (list
               name
               (list (list "label" (strcat name "test")))
               (list "spacer")
               (vox-build-dcl-part-data typ temp_data nil)
               (list "spacer")
               vox_add_del
               (list "spacer")
               vox_ok_cancel_help
               )
            )
      (setq dcl_name (load_dialog (setq dcl_temp_file (vox-build-dynamic-dcl-data name_dcl))))
      (new_dialog name dcl_name)
      (action_tile "add" "(done_dialog 2)")
      (action_tile "del" "(done_dialog 3)")
      (vox-zeig-logo)
      (setq weiter (start_dialog))
      (unload_dialog dcl_name)
      (vl-file-delete dcl_temp_file)
      (if (= weiter 2) ;add
        (setq temp_data (append temp_data (list (strcat (car temp_data) (itoa (length temp_data))))))
      )
      (if (= weiter 3) ;del
        (if (> (length temp_data) 1) (setq temp_data (reverse (cdr (reverse temp_data)))) (alert "Mindesten 1 Feld erforderlich!"))
      )
    )
  )
  (if (= weiter 1) (setq data (list typ temp_data)) (setq data data))
)


(defun vox-zeig-logo (/ imgx imgy)
  (setq imgx (dimx_tile "VOX_img"))
  (setq imgy (dimy_tile "VOX_img"))
  (start_image "VOX_img")
  (fill_image 0 0 imgx imgy -15)
  (slide_image 1 1 imgx imgy "logo")
  (end_image)
)


(prompt "geben Sie <dcltest> zum testen ein.")(prompt "\n")
(prompt "geben Sie <konvert-dcl2liste> zum Konvertieren ein.")(prin1)
